@@ -120,9 +120,15 @@ def time_range(dt, ticker, session='allday', tz='UTC', **kwargs) -> intervals.Se
     ex_info = const.exch_info(ticker=ticker, **kwargs)
     cur_dt = pd.Timestamp(dt).strftime('%Y-%m-%d')
     time_fmt = '%Y-%m-%dT%H:%M:%S'
-    time_idx = pd.DatetimeIndex([
-        f'{cur_dt} {ss.start_time}', f'{cur_dt} {ss.end_time}']
-    ).tz_localize(ex_info.tz).tz_convert(DEFAULT_TZ).tz_convert(tz)
+    time_idx = (
+        pd.DatetimeIndex([
+            f'{cur_dt} {ss.start_time}',
+            f'{cur_dt} {ss.end_time}'],
+        )
+        .tz_localize(ex_info.tz)
+        .tz_convert(DEFAULT_TZ)
+        .tz_convert(tz)
+    )
     if time_idx[0] > time_idx[1]: time_idx -= pd.TimedeltaIndex(['1D', '0D'])
     return intervals.Session(time_idx[0].strftime(time_fmt), time_idx[1].strftime(time_fmt))
 
@@ -267,7 +273,8 @@ def elem_value(element: conn.blpapi.Element):
         value
     """
     if element.isNull(): return None
-    value = element.getValue()
+    try: value = element.getValue()
+    except ValueError: return None
     if isinstance(value, np.bool_): return bool(value)
     if isinstance(value, conn.blpapi.name.Name): return str(value)
     return value
@@ -294,3 +301,15 @@ def earning_pct(data: pd.DataFrame, yr):
                 100 * data[yr].iloc[sub_pct] / data[yr].iloc[sub_pct].sum()
             sub_pct = []
         if snap.level == 2: sub_pct.append(r)
+
+
+def check_current(dt, logger, **kwargs) -> bool:
+    """
+    Check current time against T-1
+    """
+    t_1 = pd.Timestamp('today').date() - pd.Timedelta('1D')
+    whole_day = pd.Timestamp(dt).date() < t_1
+    if (not whole_day) and kwargs.get('batch', False):
+        logger.warning(f'Querying date {t_1} is too close, ignoring download ...')
+        return False
+    return True
